@@ -19,7 +19,7 @@ my $has_PDL_stats_basic = $@ ? undef : 1;
 #  to hide the piddle from the caller to avoid arbitrary changes
 #  being applied to it.
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 our $Tolerance = 0.0;  #  for compatibility with Stats::Descr, but not used here
 
@@ -354,6 +354,10 @@ sub percentile {
 
     die "Percentile $p outside range 0..100"
       if $p < 0 or $p > 100;
+    
+    #  allow for other number formats like '005'
+    #  needed for cache
+    $p += 0;
 
     return $self->{_cache}{percentile}{$p}
       if defined $self->{_cache}{percentile}{$p};
@@ -397,7 +401,7 @@ Statistics::Descriptive using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
